# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class PageHeader(Component):
    """A PageHeader component.
A header with common actions and design elements built in.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- back_icon (a list of or a singular dash component, string or number; optional):
    Custom back icon, if False the back icon will not be displayed.

- breadcrumb_routes (list of dicts; optional):
    Routes for breadcrumbs to be displayed in page header.

    `breadcrumb_routes` is a list of dicts with keys:

    - breadcrumbName (string; required)

    - children (list of dicts; required)

        `children` is a list of dicts with keys:

        - breadcrumbName (string; required)

        - path (string; required)

    - path (string; required)

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- extra (a list of or a singular dash component, string or number; optional):
    Operating area, at the end of the line of the title line.

- footer (a list of or a singular dash component, string or number; optional):
    PageHeader's footer, generally used to render TabBar.

- ghost (boolean; optional):
    PageHeader type, will change background color.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- sub_title (a list of or a singular dash component, string or number; optional):
    Custom subtitle text.

- title (a list of or a singular dash component, string or number; optional):
    Custom title text."""
    @_explicitize_args
    def __init__(self, children=None, back_icon=Component.UNDEFINED, breadcrumb_routes=Component.UNDEFINED, extra=Component.UNDEFINED, footer=Component.UNDEFINED, ghost=Component.UNDEFINED, sub_title=Component.UNDEFINED, title=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'back_icon', 'breadcrumb_routes', 'class_name', 'extra', 'footer', 'ghost', 'key', 'style', 'sub_title', 'title']
        self._type = 'PageHeader'
        self._namespace = 'dash_antd'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'back_icon', 'breadcrumb_routes', 'class_name', 'extra', 'footer', 'ghost', 'key', 'style', 'sub_title', 'title']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(PageHeader, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Col(Component):
    """A Col component.
Col

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- flex (string | number; optional):
    Flex layout style.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- lg (number | dict; optional):
    screen ≥ 992px, could be a span value or an object containing
    above props.

- md (number | dict; optional):
    screen ≥ 768px, could be a span value or an object containing
    above props.

- offset (number; optional):
    The number of cells to offset Col from the left.

- order (number; optional):
    Raster order.

- pull (number; optional):
    The number of cells that raster is moved to the left.

- push (number; optional):
    The number of cells that raster is moved to the right.

- sm (number | dict; optional):
    screen ≥ 576px, could be a span value or an object containing
    above props.

- span (number; optional):
    Raster number of cells to occupy, 0 corresponds to display: none.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- xl (number | dict; optional):
    screen ≥ 1200px, could be a span value or an object containing
    above props.

- xs (number | dict; optional):
    screen < 576px and also default setting, could be a span value or
    an object containing above props.

- xxl (number | dict; optional):
    screen ≥ 1600px, could be a span value or an object containing
    above props."""
    @_explicitize_args
    def __init__(self, children=None, flex=Component.UNDEFINED, offset=Component.UNDEFINED, order=Component.UNDEFINED, pull=Component.UNDEFINED, push=Component.UNDEFINED, span=Component.UNDEFINED, xs=Component.UNDEFINED, sm=Component.UNDEFINED, md=Component.UNDEFINED, lg=Component.UNDEFINED, xl=Component.UNDEFINED, xxl=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'class_name', 'flex', 'key', 'lg', 'md', 'offset', 'order', 'pull', 'push', 'sm', 'span', 'style', 'xl', 'xs', 'xxl']
        self._type = 'Col'
        self._namespace = 'dash_antd'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'class_name', 'flex', 'key', 'lg', 'md', 'offset', 'order', 'pull', 'push', 'sm', 'span', 'style', 'xl', 'xs', 'xxl']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Col, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class PageHeaderOperation(Component):
    """A PageHeaderOperation component.
Wrapper component to place content in the Operations section of a PageHeader

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, key=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'key']
        self._type = 'PageHeaderOperation'
        self._namespace = 'dash_antd'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'key']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(PageHeaderOperation, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Select(Component):
    """A Select component.
A dropdown component

Keyword arguments:

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- allow_clear (boolean; optional):
    Show clear button.

- auto_clear_search_value (boolean; optional):
    Whether the current search will be cleared on selecting an item.
    Only applies when mode is set to multiple or tags.

- bordered (boolean; optional):
    Whether has border style.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- clear_icon (string; optional):
    The custom clear icon.

- default_active_first_option (boolean; optional):
    Whether to activate first option by default.

- disabled (boolean; optional):
    Whether disabled select.

- dropdown_class_name (string; optional):
    The className of dropdown menu.

- dropdown_match_select_width (number; optional):
    Determine whether the dropdown menu and the select input are the
    same width. Default set min-width same as input. Will ignore when
    value less than select width False will disable virtual scroll.

- dropdown_style (dict; optional):
    The style of dropdown menu.

- fieldNames (dict; optional):
    Customize node label, value, options field name.

- filter_option (boolean; optional):
    If True, filter options by input.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- label_in_value (boolean; optional):
    Whether to embed label in value, turn the format of value from
    string to { value: string, label: ReactNode }.

- list_height (number; optional):
    Config popup height.

- loading (boolean; optional):
    Indicate loading state.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; required):
        Holds the name of the component that is loading.

    - is_loading (boolean; required):
        Determines if the component is loading or not.

    - prop_name (string; required):
        Holds which property is loading.

- max_tag_count (number; optional):
    Max tag count to show. responsive will cost render performance.

- max_tag_text_length (number; optional):
    Max tag text length to show.

- menu_item_selected_icon (string; optional):
    The custom menuItemSelected icon with multiple options.

- mode (a value equal to: 'multiple', 'tags'; optional):
    Set mode of Select.

- n_blur (number; default 0):
    Number of times the input lost focus.

- n_blur_timestamp (number; default -1):
    Last time the input lost focus.

- n_submit (number; default 0):
    Number of times the `Enter` key was pressed while the input had
    focus.

- n_submit_timestamp (number; default -1):
    Last time that `Enter` was pressed.

- open (boolean; optional):
    Controlled open state of dropdown.

- option_filter_prop (string; optional):
    Which prop value of option will be used for filter if filterOption
    is True. If options is set, it should be set to 'label'.

- option_label_prop (string; optional):
    Which prop value of option will render as content of select.

- options (list of dicts; optional):
    Select options. Will get better perf than jsx definition        {
    label, value }[].

- placeholder (string; optional):
    Placeholder of select.

- placement (a value equal to: 'bottomLeft', 'bottomRight', 'topLeft', 'topRight'; optional):
    The position where the selection box pops up.

- remove_icon (string; optional):
    The custom remove icon.

- show_arrow (boolean; optional):
    Whether to show the drop-down arrow.

- show_search (boolean; optional):
    Whether show search input in single mode.

- size (a value equal to: 'large', 'middle', 'small'; optional):
    Size of Select input.

- status (a value equal to: 'error', 'warning'; optional):
    Set validation status.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- suffix_icon (string; optional):
    The custom suffix icon.

- token_separators (list of strings; optional):
    Separator used to tokenize, only applies when mode=\"tags\".

- value (string | number | list of strings | list of numbers; optional):
    Current selected option (considered as a immutable array).

- virtual (boolean; optional):
    Disable virtual scroll when set to False."""
    @_explicitize_args
    def __init__(self, allow_clear=Component.UNDEFINED, auto_clear_search_value=Component.UNDEFINED, bordered=Component.UNDEFINED, clear_icon=Component.UNDEFINED, default_active_first_option=Component.UNDEFINED, disabled=Component.UNDEFINED, dropdown_class_name=Component.UNDEFINED, dropdown_match_select_width=Component.UNDEFINED, dropdown_style=Component.UNDEFINED, fieldNames=Component.UNDEFINED, filter_option=Component.UNDEFINED, label_in_value=Component.UNDEFINED, list_height=Component.UNDEFINED, loading=Component.UNDEFINED, max_tag_count=Component.UNDEFINED, max_tag_text_length=Component.UNDEFINED, menu_item_selected_icon=Component.UNDEFINED, mode=Component.UNDEFINED, open=Component.UNDEFINED, option_filter_prop=Component.UNDEFINED, option_label_prop=Component.UNDEFINED, options=Component.UNDEFINED, placeholder=Component.UNDEFINED, placement=Component.UNDEFINED, remove_icon=Component.UNDEFINED, show_arrow=Component.UNDEFINED, show_search=Component.UNDEFINED, size=Component.UNDEFINED, status=Component.UNDEFINED, suffix_icon=Component.UNDEFINED, token_separators=Component.UNDEFINED, value=Component.UNDEFINED, virtual=Component.UNDEFINED, loading_state=Component.UNDEFINED, n_blur=Component.UNDEFINED, n_blur_timestamp=Component.UNDEFINED, n_submit=Component.UNDEFINED, n_submit_timestamp=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'allow_clear', 'auto_clear_search_value', 'bordered', 'class_name', 'clear_icon', 'default_active_first_option', 'disabled', 'dropdown_class_name', 'dropdown_match_select_width', 'dropdown_style', 'fieldNames', 'filter_option', 'key', 'label_in_value', 'list_height', 'loading', 'loading_state', 'max_tag_count', 'max_tag_text_length', 'menu_item_selected_icon', 'mode', 'n_blur', 'n_blur_timestamp', 'n_submit', 'n_submit_timestamp', 'open', 'option_filter_prop', 'option_label_prop', 'options', 'placeholder', 'placement', 'remove_icon', 'show_arrow', 'show_search', 'size', 'status', 'style', 'suffix_icon', 'token_separators', 'value', 'virtual']
        self._type = 'Select'
        self._namespace = 'dash_antd'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'allow_clear', 'auto_clear_search_value', 'bordered', 'class_name', 'clear_icon', 'default_active_first_option', 'disabled', 'dropdown_class_name', 'dropdown_match_select_width', 'dropdown_style', 'fieldNames', 'filter_option', 'key', 'label_in_value', 'list_height', 'loading', 'loading_state', 'max_tag_count', 'max_tag_text_length', 'menu_item_selected_icon', 'mode', 'n_blur', 'n_blur_timestamp', 'n_submit', 'n_submit_timestamp', 'open', 'option_filter_prop', 'option_label_prop', 'options', 'placeholder', 'placement', 'remove_icon', 'show_arrow', 'show_search', 'size', 'status', 'style', 'suffix_icon', 'token_separators', 'value', 'virtual']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Select, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Tabs(Component):
    """A Tabs component.
Tabs

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- add_icon (string; optional):
    Customize add icon.

- animated (boolean; optional):
    Whether to change tabs with animation. Only works while
    tabPosition=\"top\".

- centered (boolean; optional):
    Centers tabs.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- destroy_inactive_tab_pane (boolean; optional):
    Whether destroy inactive TabPane when tab is changed.

- hide_add (boolean; optional):
    Hide plus icon or not. Only works while type=\"editable-card\".

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- more_icon (string; optional):
    The custom icon of ellipsis.

- size (a value equal to: 'large', 'middle', 'small'; optional):
    Preset tab bar size.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- tab_bar_gutter (number; optional):
    The gap between tabs.

- tab_bar_style (dict; optional):
    Tab bar style object.

- tab_position (a value equal to: 'top', 'right', 'bottom', 'left'; optional):
    Position of tabs.

- type (a value equal to: 'line', 'card', 'editable-card'; optional):
    Basic style of tabs.

- value (string; optional):
    Current TabPane's key."""
    @_explicitize_args
    def __init__(self, children=None, value=Component.UNDEFINED, add_icon=Component.UNDEFINED, animated=Component.UNDEFINED, centered=Component.UNDEFINED, hide_add=Component.UNDEFINED, more_icon=Component.UNDEFINED, size=Component.UNDEFINED, tab_bar_gutter=Component.UNDEFINED, tab_bar_style=Component.UNDEFINED, tab_position=Component.UNDEFINED, destroy_inactive_tab_pane=Component.UNDEFINED, type=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'add_icon', 'animated', 'centered', 'class_name', 'destroy_inactive_tab_pane', 'hide_add', 'key', 'more_icon', 'size', 'style', 'tab_bar_gutter', 'tab_bar_style', 'tab_position', 'type', 'value']
        self._type = 'Tabs'
        self._namespace = 'dash_antd'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'add_icon', 'animated', 'centered', 'class_name', 'destroy_inactive_tab_pane', 'hide_add', 'key', 'more_icon', 'size', 'style', 'tab_bar_gutter', 'tab_bar_style', 'tab_position', 'type', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Tabs, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Alert(Component):
    """An Alert component.
Alert component for feedback.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- banner (boolean; optional):
    Whether to show as banner.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- closable (boolean; optional):
    Whether Alert can be closed.

- close_icon (string; optional):
    Custom close icon.

- close_text (string; optional):
    Close text to show.

- description (string; optional):
    Additional content of Alert.

- icon (string; optional):
    Custom icon, effective when showIcon is True.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- message (string; optional):
    Content of Alert.

- show_icon (boolean; optional):
    Whether to show icon.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- type (a value equal to: 'success', 'info', 'warning', 'error'; optional):
    Type of Alert."""
    @_explicitize_args
    def __init__(self, children=None, banner=Component.UNDEFINED, closable=Component.UNDEFINED, close_text=Component.UNDEFINED, close_icon=Component.UNDEFINED, description=Component.UNDEFINED, icon=Component.UNDEFINED, message=Component.UNDEFINED, show_icon=Component.UNDEFINED, type=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'banner', 'class_name', 'closable', 'close_icon', 'close_text', 'description', 'icon', 'key', 'message', 'show_icon', 'style', 'type']
        self._type = 'Alert'
        self._namespace = 'dash_antd'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'banner', 'class_name', 'closable', 'close_icon', 'close_text', 'description', 'icon', 'key', 'message', 'show_icon', 'style', 'type']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Alert, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class InputNumber(Component):
    """An InputNumber component.
InputNumber

Keyword arguments:

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- addon_after (string; optional):
    The label text displayed after (on the right side of) the input
    field.

- addon_before (string; optional):
    The label text displayed before (on the left side of) the input
    field.

- bordered (boolean; optional):
    Whether has border style.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- controls (boolean; optional):
    Whether to show +- controls.

- debounce (boolean; default False):
    If True, changes to input will be sent back to the Dash server
    only when the enter key is pressed or when the component loses
    focus.  If it's False, it will sent the value back on every
    change.

- disabled (boolean; optional):
    Whether the input is disabled.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; required):
        Holds the name of the component that is loading.

    - is_loading (boolean; required):
        Determines if the component is loading or not.

    - prop_name (string; required):
        Holds which property is loading.

- max (number; optional):
    The max value.

- min (number; optional):
    The min value.

- n_blur (number; default 0):
    Number of times the input lost focus.

- n_blur_timestamp (number; default -1):
    Last time the input lost focus.

- n_submit (number; default 0):
    Number of times the `Enter` key was pressed while the input had
    focus.

- n_submit_timestamp (number; default -1):
    Last time that `Enter` was pressed.

- precision (number; optional):
    The precision of input value.

- prefix (string; optional):
    The prefix icon for the Input.

- read_only (boolean; optional):
    If readonly the input.

- size (a value equal to: 'large', 'middle', 'small'; optional):
    The height of input box.

- status (a value equal to: 'error', 'warning'; optional):
    Set validation status.

- step (string | number; default 1):
    The number to which the current value is increased or decreased.
    It can be an integer or decimal.

- string_mode (boolean; optional):
    Set value as string to support high precision decimals.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- value (number; default 0):
    The current value."""
    @_explicitize_args
    def __init__(self, addon_after=Component.UNDEFINED, addon_before=Component.UNDEFINED, bordered=Component.UNDEFINED, controls=Component.UNDEFINED, debounce=Component.UNDEFINED, disabled=Component.UNDEFINED, max=Component.UNDEFINED, min=Component.UNDEFINED, precision=Component.UNDEFINED, read_only=Component.UNDEFINED, status=Component.UNDEFINED, prefix=Component.UNDEFINED, size=Component.UNDEFINED, step=Component.UNDEFINED, string_mode=Component.UNDEFINED, value=Component.UNDEFINED, n_blur=Component.UNDEFINED, n_blur_timestamp=Component.UNDEFINED, n_submit=Component.UNDEFINED, n_submit_timestamp=Component.UNDEFINED, loading_state=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'addon_after', 'addon_before', 'bordered', 'class_name', 'controls', 'debounce', 'disabled', 'key', 'loading_state', 'max', 'min', 'n_blur', 'n_blur_timestamp', 'n_submit', 'n_submit_timestamp', 'precision', 'prefix', 'read_only', 'size', 'status', 'step', 'string_mode', 'style', 'value']
        self._type = 'InputNumber'
        self._namespace = 'dash_antd'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'addon_after', 'addon_before', 'bordered', 'class_name', 'controls', 'debounce', 'disabled', 'key', 'loading_state', 'max', 'min', 'n_blur', 'n_blur_timestamp', 'n_submit', 'n_submit_timestamp', 'precision', 'prefix', 'read_only', 'size', 'status', 'step', 'string_mode', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(InputNumber, self).__init__(**args)



from .Alert import Alert
from .Button import Button
from .Card import Card
from .CardAction import CardAction
from .CardExtra import CardExtra
from .CheckableTag import CheckableTag
from .Checkbox import Checkbox
from .CheckboxGroup import CheckboxGroup
from .Col import Col
from .Content import Content
from .DatePicker import DatePicker
from .DateRangePicker import DateRangePicker
from .Divider import Divider
from .DropdownButton import DropdownButton
from .DropdownMenu import DropdownMenu
from .Footer import Footer
from .Header import Header
from .Icon import Icon
from .Input import Input
from .InputNumber import InputNumber
from .Layout import Layout
from .Menu import Menu
from .MenuItem import MenuItem
from .PageHeader import PageHeader
from .PageHeaderFooter import PageHeaderFooter
from .PageHeaderOperation import PageHeaderOperation
from .Radio import Radio
from .RadioButton import RadioButton
from .RadioGroup import RadioGroup
from .Row import Row
from .Select import Select
from .Sidebar import Sidebar
from .Slider import Slider
from .Space import Space
from .Step import Step
from .Steps import Steps
from .Switch import Switch
from .TabPane import TabPane
from .Tabs import Tabs
from .Tag import Tag
from .TextArea import TextArea
from .TimePicker import TimePicker
from .TimeRangePicker import TimeRangePicker

__all__ = [
    "Alert",
    "Button",
    "Card",
    "CardAction",
    "CardExtra",
    "Checkbox",
    "CheckboxGroup",
    "DatePicker",
    "DateRangePicker",
    "TimePicker",
    "TimeRangePicker",
    "Divider",
    "DropdownButton",
    "DropdownMenu",
    "Icon",
    "Input",
    "InputNumber",
    "TextArea",
    "Col",
    "Content",
    "Footer",
    "Header",
    "Layout",
    "Row",
    "Sidebar",
    "Menu",
    "MenuItem",
    "PageHeader",
    "PageHeaderFooter",
    "PageHeaderOperation",
    "Radio",
    "RadioButton",
    "RadioGroup",
    "Select",
    "Slider",
    "Space",
    "Step",
    "Steps",
    "Switch",
    "TabPane",
    "Tabs",
    "CheckableTag",
    "Tag",
]



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Menu(Component):
    """A Menu component.
A versatile menu for navigation.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- expand_icon (a list of or a singular dash component, string or number; optional):
    custom expand icon of submenu.

- force_sub_menu_render (boolean; optional):
    Render submenu into DOM before it becomes visible.

- inline_collapsed (boolean; optional):
    Specifies the collapsed status when menu is inline mode.

- inline_indent (number; optional):
    Indent (in pixels) of inline menu items on each level.

- items (list of boolean | number | string | dict | lists; optional):
    Menu item content.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- mode (a value equal to: 'vertical', 'horizontal', 'inline'; optional):
    Type of menu.

- multiple (boolean; optional):
    Allows selection of multiple items.

- open_keys (list of strings; optional):
    Array with the keys of currently opened sub-menus.

- overflowed_indicator (a list of or a singular dash component, string or number; optional):
    Customized the ellipsis icon when menu is collapsed horizontally.

- selectable (boolean; default True):
    Allows selecting menu items.

- selected_keys (list of strings; optional):
    Array with the keys of currently selected menu items.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- sub_menu_close_delay (number; optional):
    Delay time to hide submenu when mouse leaves (in seconds).

- sub_menu_open_delay (number; optional):
    Delay time to show submenu when mouse enters, (in seconds).

- theme (a value equal to: 'light', 'dark'; optional):
    Color theme of the menu."""
    @_explicitize_args
    def __init__(self, children=None, expand_icon=Component.UNDEFINED, force_sub_menu_render=Component.UNDEFINED, inline_collapsed=Component.UNDEFINED, inline_indent=Component.UNDEFINED, items=Component.UNDEFINED, mode=Component.UNDEFINED, multiple=Component.UNDEFINED, open_keys=Component.UNDEFINED, overflowed_indicator=Component.UNDEFINED, selectable=Component.UNDEFINED, selected_keys=Component.UNDEFINED, sub_menu_close_delay=Component.UNDEFINED, sub_menu_open_delay=Component.UNDEFINED, theme=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'class_name', 'expand_icon', 'force_sub_menu_render', 'inline_collapsed', 'inline_indent', 'items', 'key', 'mode', 'multiple', 'open_keys', 'overflowed_indicator', 'selectable', 'selected_keys', 'style', 'sub_menu_close_delay', 'sub_menu_open_delay', 'theme']
        self._type = 'Menu'
        self._namespace = 'dash_antd'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'class_name', 'expand_icon', 'force_sub_menu_render', 'inline_collapsed', 'inline_indent', 'items', 'key', 'mode', 'multiple', 'open_keys', 'overflowed_indicator', 'selectable', 'selected_keys', 'style', 'sub_menu_close_delay', 'sub_menu_open_delay', 'theme']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Menu, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Steps(Component):
    """A Steps component.
Steps

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    Unique ID to identify this component in Dash callbacks.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- current (number; optional):
    To set the current step, counting from 0. You can overwrite this
    state by using status of Step.

- direction (a value equal to: 'horizontal', 'vertical'; optional):
    To specify the direction of the step bar, horizontal or vertical.

- initial (number; optional):
    Set the initial step, counting from 0.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- label_placement (a value equal to: 'horizontal', 'vertical'; optional):
    Place title and description with horizontal or vertical direction.

- percent (number; optional):
    Progress circle percentage of current step in process status (only
    works on basic Steps).

- progress_dot (boolean; optional):
    Steps with progress dot style.

- responsive (boolean; optional):
    Change to vertical direction when screen width smaller than 532px.

- size (a value equal to: 'default', 'small'; optional):
    To specify the size of the step bar.

- status (a value equal to: 'wait', 'process', 'finish', 'error'; optional):
    Specify the status of current step.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- type (a value equal to: 'default', 'navigation'; optional):
    Type of steps."""
    @_explicitize_args
    def __init__(self, children=None, current=Component.UNDEFINED, direction=Component.UNDEFINED, initial=Component.UNDEFINED, label_placement=Component.UNDEFINED, percent=Component.UNDEFINED, progress_dot=Component.UNDEFINED, responsive=Component.UNDEFINED, size=Component.UNDEFINED, status=Component.UNDEFINED, type=Component.UNDEFINED, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'class_name', 'current', 'direction', 'initial', 'key', 'label_placement', 'percent', 'progress_dot', 'responsive', 'size', 'status', 'style', 'type']
        self._type = 'Steps'
        self._namespace = 'dash_antd'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'class_name', 'current', 'direction', 'initial', 'key', 'label_placement', 'percent', 'progress_dot', 'responsive', 'size', 'status', 'style', 'type']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Steps, self).__init__(children=children, **args)
